@@ -279,7 +279,7 @@
 #'   
 #' 
 #' @name poppr-package
-#' @docType package
+"_PACKAGE"
 #==============================================================================#
 NULL
 #==============================================================================#
